==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/main.cpp <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/


#include <QApplication>
#include <QtGui>
#include "includes/httraqt.h"
#include "../version.h"


int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
#if 0
    QPixmap logo(":/images/splash.png");
    QPainter painter(&logo);
    painter.setFont(QFont("Arial", 15));

    QSplashScreen* splash = new QSplashScreen(logo);
    splash->show();
    splash->showMessage(QObject::tr(PROGRAM_FULL_NAME), Qt::AlignLeft | Qt::AlignBottom);
#endif

    HTTraQt* mainWidget;
    QString pName = QString().sprintf("%s v.%s", PROGRAM_NAME, HTTQTVERSION);
    mainWidget = new HTTraQt(0, Qt::Window);
    mainWidget->setLangGUI();
    mainWidget->setWindowTitle(pName);

    mainWidget->show();

    return app.exec();
}

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/main.cpp <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/


#include <QApplication>
#include <QtGui>
#include "includes/httraqt.h"
#include "../version.h"


int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
#if 0
    QPixmap logo(":/images/splash.png");
    QPainter painter(&logo);
    painter.setFont(QFont("Arial", 15));

    QSplashScreen* splash = new QSplashScreen(logo);
    splash->show();
    splash->showMessage(QObject::tr(PROGRAM_FULL_NAME), Qt::AlignLeft | Qt::AlignBottom);
#endif

    HTTraQt* mainWidget;
    QString pName = QString(PROGRAM_NAME) + " v." + QString(HTTQTVERSION);
    mainWidget = new HTTraQt(0, Qt::Window);
    mainWidget->setLangGUI();
    mainWidget->setWindowTitle(pName);

    mainWidget->show();

    return app.exec();
}
